@@ -130,22 +130,14 @@ wp_props_load_wallpaper (gchar *key,
   pixbuf = gnome_wp_item_get_thumbnail (item, data->wp_thumbs);
   gnome_wp_item_update_description (item);
 
+  gtk_list_store_set (GTK_LIST_STORE (data->wp_model), &iter,
+                      0, pixbuf,
+                      1, item->description,
+                      2, item->filename,
+                      -1);
+
   if (pixbuf != NULL)
-  {
-    gtk_list_store_set (GTK_LIST_STORE (data->wp_model), &iter,
-                        0, pixbuf,
-                        1, item->description,
-                        2, item->filename,
-                        -1);
     g_object_unref (pixbuf);
-  }
-  else
-  {
-    gtk_list_store_set (GTK_LIST_STORE (data->wp_model), &iter,
-                        1, item->description,
-                        2, item->filename,
-                        -1);
-  }
 
   path = gtk_tree_model_get_path (data->wp_model, &iter);
   item->rowref = gtk_tree_row_reference_new (data->wp_model, path);
@@ -350,7 +342,8 @@ wp_scale_type_changed (GtkComboBox *combobox,
                       &iter,
                       0, pixbuf,
                       -1);
-  g_object_unref (pixbuf);
+  if (pixbuf != NULL)
+    g_object_unref (pixbuf);
 
   gconf_client_set_string (data->client, WP_OPTIONS_KEY, item->options, NULL);
 }
@@ -391,7 +384,9 @@ wp_shade_type_changed (GtkWidget *combobox,
   gtk_list_store_set (GTK_LIST_STORE (data->wp_model), &iter,
                       0, pixbuf,
                       -1);
-  g_object_unref (pixbuf);
+  if (pixbuf != NULL)
+    g_object_unref (pixbuf);
+
   gconf_client_set_string (data->client, WP_SHADING_KEY,
                            item->shade_type, NULL);
 }
@@ -679,21 +674,6 @@ wp_file_open_dialog (GtkWidget *widget,
   }
 }
 
-static void
-appearance_window_response (GtkWidget *widget,
-                            gint response_id,
-                            AppearanceData *data)
-{
-  if (response_id == GTK_RESPONSE_CLOSE ||
-      response_id == GTK_RESPONSE_DELETE_EVENT)
-  {
-    gnome_wp_xml_save_list (data);
-    g_object_unref (data->wp_thumbs);
-    g_object_ref_sink (data->wp_filesel);
-    g_object_unref (data->wp_filesel);
-  }
-}
-
 static void
 wp_dragged_image (GtkWidget *widget,
                   GdkDragContext *context,
@@ -735,6 +715,38 @@ wp_dragged_image (GtkWidget *widget,
   }
 }
 
+#if GTK_CHECK_VERSION (2,11,0)
+static gboolean
+wp_view_tooltip_cb (GtkWidget  *widget,
+                    gint x,
+                    gint y,
+                    gboolean keyboard_mode,
+                    GtkTooltip *tooltip,
+                    AppearanceData *data)
+{
+  GtkTreePath *path;
+  GtkTreeIter iter;
+  gchar *wpfile;
+  GnomeWPItem *item;
+
+  path = gtk_icon_view_get_path_at_pos (data->wp_view, x, y);
+
+  if (path == NULL)
+    return FALSE;
+
+  gtk_tree_model_get_iter (data->wp_model, &iter, path);
+  gtk_tree_path_free (path);
+
+  gtk_tree_model_get (data->wp_model, &iter, 2, &wpfile, -1);
+  item = g_hash_table_lookup (data->wp_hash, wpfile);
+
+  gtk_tooltip_set_markup (tooltip,
+                          g_strdup_printf ("%s", item->description));
+
+  return TRUE;
+}
+#endif
+
 static gint
 wp_list_sort (GtkTreeModel *model,
               GtkTreeIter *a, GtkTreeIter *b,
@@ -909,8 +921,15 @@ desktop_init (AppearanceData *data)
   GtkWidget *add_button;
   GtkFileFilter *filter;
 
+#if GTK_CHECK_VERSION (2,11,0)
+  GtkSettings *settings;
+
+  settings = gtk_settings_get_default ();
+  g_object_set (G_OBJECT (settings), "gtk-tooltip-timeout", 500, NULL);
+#endif
+
   data->wp_update_gconf = TRUE;
-  
+
   data->wp_hash = g_hash_table_new (g_str_hash, g_str_equal);
 
   data->wp_thumbs = gnome_thumbnail_factory_new (GNOME_THUMBNAIL_SIZE_NORMAL);
@@ -945,12 +964,13 @@ desktop_init (AppearanceData *data)
                                                  G_TYPE_STRING,
                                                  G_TYPE_STRING));
 
-  g_signal_connect_after (G_OBJECT (glade_xml_get_widget (data->xml, "appearance_window")), "response",
-                          G_CALLBACK (appearance_window_response), data);
-
   data->wp_view = GTK_ICON_VIEW (glade_xml_get_widget (data->xml, "wp_view"));
   gtk_icon_view_set_model (data->wp_view, GTK_TREE_MODEL (data->wp_model));
 
+#if GTK_CHECK_VERSION (2,11,0)
+  g_object_set (G_OBJECT (data->wp_view), "has-tooltip", TRUE, NULL);
+#endif
+
   g_signal_connect_after (G_OBJECT (data->wp_view), "realize",
                           G_CALLBACK (wp_select_after_realize), data);
 
@@ -962,7 +982,7 @@ desktop_init (AppearanceData *data)
                 "xpad", 5,
                 "ypad", 5,
                 NULL);
-  
+
   gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (data->wp_view),
                               data->wp_cell,
                               TRUE);
@@ -1020,6 +1040,11 @@ desktop_init (AppearanceData *data)
   g_signal_connect (G_OBJECT (data->wp_view), "selection-changed",
                     G_CALLBACK (wp_props_wp_selected), data);
 
+#if GTK_CHECK_VERSION (2,11,0)
+  g_signal_connect (G_OBJECT (data->wp_view), "query-tooltip",
+                    G_CALLBACK (wp_view_tooltip_cb), data);
+#endif
+
   wp_set_sensitivities (data);
 
   data->wp_filesel = gtk_file_chooser_dialog_new_with_backend (_("Add Wallpaper"),
@@ -1057,3 +1082,12 @@ desktop_init (AppearanceData *data)
   g_signal_connect (data->wp_filesel, "update-preview",
                     G_CALLBACK (wp_update_preview), data);
 }
+
+void
+desktop_shutdown (AppearanceData *data)
+{
+  gnome_wp_xml_save_list (data);
+  g_object_unref (data->wp_thumbs);
+  g_object_ref_sink (data->wp_filesel);
+  g_object_unref (data->wp_filesel);
+}
