@@ -1,3 +1,4 @@
+#include <config.h>
 #include <unistd.h>
 #include <string.h>
 #include <metacity-private/util.h>
@@ -12,7 +13,6 @@
 #undef N_
 
 #include <libgnomeui/gnome-icon-theme.h>
-#include <config.h>
 
 #include "theme-thumbnail.h"
 #include "capplet-util.h"
@@ -34,10 +34,8 @@ typedef struct
 } ThemeThumbnailAsyncData;
 
 
-static GHashTable *theme_hash = NULL;
 static ThemeThumbnailAsyncData async_data;
 
-
 /* Protocol */
 
 /* Our protocol is pretty simple.  The parent process will write four strings
@@ -133,13 +131,13 @@ create_folder_icon (char *icon_theme_name)
     folder_icon_info = gtk_icon_theme_lookup_icon (icon_theme, "gnome-fs-directory", 48, GTK_ICON_LOOKUP_FORCE_SVG);
   if (folder_icon_info == NULL)
     folder_icon_info = gtk_icon_theme_lookup_icon (icon_theme, "folder", 48, GTK_ICON_LOOKUP_FORCE_SVG);
- 
+
   g_object_unref (icon_theme);
 
-  if (folder_icon_info != NULL) 
+  if (folder_icon_info != NULL)
   {
     filename = gtk_icon_info_get_filename (folder_icon_info);
-    
+
     if (filename != NULL)
     {
       folder_icon = gdk_pixbuf_new_from_file (filename, NULL);
@@ -154,14 +152,14 @@ create_folder_icon (char *icon_theme_name)
     GtkWidget *dummy;
     dummy = gtk_label_new ("");
 
-    folder_icon = gtk_widget_render_icon (dummy, 
-                                          GTK_STOCK_MISSING_IMAGE, 
+    folder_icon = gtk_widget_render_icon (dummy,
+                                          GTK_STOCK_MISSING_IMAGE,
                                           GTK_ICON_SIZE_DIALOG,
                                           NULL);
 
     gtk_widget_destroy (dummy);
   }
-  
+
   /* Some icons don't come back at the requested dimensions, so we need to scale
    * them. The width is usually the largest dimension for icons that come at
    * irregular sizes, so use this to calculate the scale factor
@@ -275,7 +273,7 @@ create_image (ThemeThumbnailData *theme_thumbnail_data,
   icon = create_folder_icon ((char *) theme_thumbnail_data->icon_theme_name->data);
   width = gdk_pixbuf_get_width (icon);
   height = gdk_pixbuf_get_height (icon);
-  
+
   gdk_pixbuf_composite (icon,
 			pixbuf,
 			align->allocation.x + align->allocation.width - width - 5,
@@ -480,9 +478,9 @@ message_from_child (GIOChannel   *source,
 	    memcpy (pixels + rowstride * i, async_data.data->data + 4 * ICON_SIZE_WIDTH * i, ICON_SIZE_WIDTH * 4);
 
 	  scaled_pixbuf = gdk_pixbuf_scale_simple (pixbuf, ICON_SIZE_WIDTH/2, ICON_SIZE_HEIGHT/2, GDK_INTERP_BILINEAR);
-	  g_hash_table_insert (theme_hash, g_strdup(async_data.meta_theme_name), scaled_pixbuf);
 	  g_object_unref (pixbuf);
 
+	  /* callback function needs to unref the pixbuf */
  	  (* async_data.func) (scaled_pixbuf, async_data.user_data);
 	  if (async_data.destroy)
 	    (* async_data.destroy) (async_data.user_data);
@@ -515,37 +513,15 @@ message_from_child (GIOChannel   *source,
   return TRUE;
 }
 
-void  
-theme_thumbnail_invalidate_cache (GnomeThemeMetaInfo *meta_theme_info)
-{
-  gboolean success;
-
-  success = g_hash_table_remove (theme_hash, meta_theme_info->name);
-  printf ("Success is %d\n", success);
-}
-
 GdkPixbuf *
-generate_theme_thumbnail (GnomeThemeMetaInfo *meta_theme_info,
-			  gboolean            clear_cache)
+generate_theme_thumbnail (GnomeThemeMetaInfo *meta_theme_info)
 {
   GdkPixbuf *retval = NULL;
-  GdkPixbuf *pixbuf = NULL;
+  GdkPixbuf *pixbuf;
   gint i, rowstride;
   char *pixels;
 
-  if (async_data.set == TRUE)
-	  return NULL;
-
-  pixbuf = g_hash_table_lookup (theme_hash, meta_theme_info->name);
-  if (pixbuf != NULL)
-    {
-      if (clear_cache)
-	g_hash_table_remove (theme_hash, meta_theme_info->name);
-      else
-	return pixbuf;
-    }
-
-  if (!pipe_to_factory_fd[1] || !pipe_from_factory_fd[0])
+  if (async_data.set || !pipe_to_factory_fd[1] || !pipe_from_factory_fd[0])
     return NULL;
 
   pixbuf = gdk_pixbuf_new (GDK_COLORSPACE_RGB, TRUE, 8, ICON_SIZE_WIDTH, ICON_SIZE_HEIGHT);
@@ -594,8 +570,6 @@ generate_theme_thumbnail (GnomeThemeMetaInfo *meta_theme_info,
 
   retval = gdk_pixbuf_scale_simple (pixbuf, ICON_SIZE_WIDTH/2, ICON_SIZE_HEIGHT/2, GDK_INTERP_BILINEAR);
   g_object_unref (pixbuf);
-  
-  g_hash_table_insert (theme_hash, g_strdup (meta_theme_info->name), retval);
   return retval;
 }
 
@@ -605,19 +579,8 @@ generate_theme_thumbnail_async (GnomeThemeMetaInfo *meta_theme_info,
 				gpointer            user_data,
 				GDestroyNotify      destroy)
 {
-  GdkPixbuf *pixbuf;
-
   g_return_if_fail (async_data.set == FALSE);
 
-  pixbuf = g_hash_table_lookup (theme_hash, meta_theme_info->name);
-  if (pixbuf != NULL)
-    {
-      (* func) (pixbuf, user_data);
-      if (destroy)
-	(* destroy) (user_data);
-      return;
-    }
-
   if (!pipe_to_factory_fd[1] || !pipe_from_factory_fd[0])
     {
       (* func) (NULL, user_data);
@@ -635,7 +598,6 @@ generate_theme_thumbnail_async (GnomeThemeMetaInfo *meta_theme_info,
       async_data.watch_id = g_io_add_watch (async_data.channel, G_IO_IN | G_IO_HUP, message_from_child, NULL);
     }
 
-
   async_data.set = TRUE;
   async_data.meta_theme_name = g_strdup (meta_theme_info->name);
   async_data.func = func;
@@ -701,19 +663,16 @@ theme_thumbnail_factory_init (int argc, char *argv[])
   async_data.set = FALSE;
   async_data.meta_theme_name = NULL;
   async_data.data = g_byte_array_new ();
-
-  theme_hash = g_hash_table_new_full (g_str_hash, g_str_equal, g_free, g_object_unref);
 }
 
 
-
 /* Functions for specific types of themes */
 
 GdkPixbuf *
 generate_gtk_theme_thumbnail (GnomeThemeInfo *info)
 {
   GObject *settings;
-  char *current_theme;
+  gchar *current_theme = NULL;
   GtkWidget *window, *vbox, *box, *stock_button, *checkbox, *radio;
   GtkRequisition requisition;
   GtkAllocation allocation;
@@ -727,7 +686,6 @@ generate_gtk_theme_thumbnail (GnomeThemeInfo *info)
   g_object_set (settings, "gtk-theme-name", info->name, NULL);
 
   window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
-  //gtk_window_set_default_size (GTK_WINDOW (window), ICON_SIZE_WIDTH, ICON_SIZE_HEIGHT);
 
   vbox = gtk_vbox_new (FALSE, 0);
   gtk_container_add (GTK_CONTAINER (window), vbox);
@@ -794,6 +752,7 @@ generate_gtk_theme_thumbnail (GnomeThemeInfo *info)
   gtk_widget_destroy (window);
   g_object_set (settings, "gtk-theme-name", current_theme, NULL);
   g_free (current_theme);
+
   return ret;
 }
 
@@ -808,7 +767,7 @@ generate_metacity_theme_thumbnail (GnomeThemeInfo *info)
   GdkVisual *visual;
   GdkPixmap *pixmap;
   GdkPixbuf *pixbuf, *ret;
- 
+
   theme = meta_theme_load (info->name, NULL);
 
   flags = META_FRAME_ALLOWS_DELETE |
@@ -829,10 +788,10 @@ generate_metacity_theme_thumbnail (GnomeThemeInfo *info)
   meta_preview_set_theme (META_PREVIEW (preview), theme);
   meta_preview_set_title (META_PREVIEW (preview), "");
   gtk_container_add (GTK_CONTAINER (window), preview);
-  
+
   dummy = gtk_label_new ("");
   gtk_container_add (GTK_CONTAINER (preview), dummy);
-  
+
   gtk_widget_realize (window);
   gtk_widget_realize (preview);
   gtk_widget_realize (dummy);
@@ -862,10 +821,10 @@ generate_metacity_theme_thumbnail (GnomeThemeInfo *info)
 
   pixbuf = gdk_pixbuf_new (GDK_COLORSPACE_RGB, TRUE, 8, ICON_SIZE_WIDTH, ICON_SIZE_WIDTH / 2);
   gdk_pixbuf_get_from_drawable (pixbuf, pixmap, NULL, 0, 0, 0, 0, ICON_SIZE_WIDTH, ICON_SIZE_WIDTH / 2);
-  
+
   ret = gdk_pixbuf_scale_simple (pixbuf, 96, 48, GDK_INTERP_BILINEAR);
   g_object_unref (pixbuf);
-  
+
   gtk_widget_destroy (window);
   return ret;
 }
